searchNodes=[{"doc":"A module for generating coupon codes in Elixir. Inspired by the Perl library CouponCode, a coupon code is a group of letters and numbers known as part and separated by a hyphen(-) that is meant for a receipient types in. For example, a 3 part code with 4 characters per part looks like this: H6YV-UDPL-383N Like with the original module, it has the same features: Codes are validated regardless of case (upper or lower) Codes use the upper cased letters and numbers; however, it does not use the letters &quot;O&quot;, &quot;I&quot;, &quot;Z&quot; and &quot;S&quot; since they are visually similar to &quot;0&quot;, &quot;1&quot;, &quot;2&quot; and &quot;5&quot;. Still, the receipient can enter those ambigious letters and be considered valid or corrected. The last character of every part is a checkdigit that helps in determining which specifc part(s) has been entered correctly. Generated parts are also rejected against a list of bad words since they are manually entered. Generated parts that can be transposed (or for example with a 4 character part ABCD, the parts BACD. ACBD and ABDC generate a valid checkdigit) are also rejected. Config While this library has good defaults, it can be configured like so: config :coupon_code_ex, parts: 3 part_length: 4 bad_words: ~w(SHPX PHAG JNAX JNAT CVFF PBPX FUVG GJNG GVGF SNEG URYY ZHSS QVPX XABO NEFR FUNT GBFF FYHG GHEQ FYNT PENC CBBC OHGG SRPX OBBO WVFZ WVMM CUNG) While part_length can have multiple values, it is discouraged to change it from the default since the bad_words is built for that length. If you still want to change it, remember to update the bad_words lists to the maximum length that is supported. When customizing the bad_words list, remember it is encoded with rot13 to avoid profanity in the code or configuraton. So right before adding a new word to that list, you can encode it with CouponCode.rot13/1 or an online rot13 encoder.","ref":"CouponCode.html","title":"CouponCode","type":"module"},{"doc":"Generate the regex used in detecting bad words from the generated codes. Aside from detecting all words in the decoded list, it should detect similar characters (0 to O, 1 to I, 2 to S and 5 to Z). Examples iex&gt; &quot;P00P&quot; =~ CouponCode.bad_word_regex() true iex&gt; &quot;POOP&quot; =~ CouponCode.bad_word_regex() true iex&gt; &quot;P00P1E&quot; =~ CouponCode.bad_word_regex() false iex&gt; &quot;F0RD&quot; =~ CouponCode.bad_word_regex() false","ref":"CouponCode.html#bad_word_regex/0","title":"CouponCode.bad_word_regex/0","type":"function"},{"doc":"Generate a random coupon code. Algorithm Like with the original module, each generated code uses a plaintext as a source of bytes. It is then hashed with sha1 and consumed for each random character that is needed (which excludes checkdigits) to generate a part. When the bytes are insufficient to generate a new part or is rejected by having a filtered word or is transposable, it is rehashed to generate and used as the new source of bytes. This process is repeated until every part is generated. Options This function takes a keyword options as the first argument: plaintext - The plaintext to use for generating the coupon code. Useful in generating the same or deterministic code with the same options but usually not filled in. If none is given, a random 8 byte plaintext is generated. parts - The number of delimited segments to generate. Defaults to 3 or Application.get_env(:coupon_code_ex, :parts) and must be a positive integer. part_length - The number of characters per each part which includes the checkdigit. Defaults to 4 or Application.get_env(:coupon_code_ex, :part_length) and must be a positive integer between 2 - 20 inclusively. (The limitation stems from sha1 generating exactly 20 bytes.) Examples iex&gt; CouponCode.generate(plaintext: &quot;1234567890&quot;) &quot;1K7Q-CTFM-LMTC&quot; iex&gt; CouponCode.generate(plaintext: &quot;123456789A&quot;) &quot;X730-KCV1-MA2G&quot; iex&gt; CouponCode.generate() &quot;5UMN-WBKJ-2MCA&quot; iex&gt; CouponCode.generate(parts: 1) &quot;YUVN&quot; iex&gt; CouponCode.generate(parts: 5) &quot;D51P-H52K-9VMD-UT5H-XE3A&quot; iex&gt; CouponCode.generate(part_length: 3) &quot;GVB-KDB-ADF&quot; iex&gt; CouponCode.generate(part: 2, part_length: 7) &quot;86NMUDX-GFEJHVR&quot;","ref":"CouponCode.html#generate/1","title":"CouponCode.generate/1","type":"function"},{"doc":"rot13 utility function to encode/decode bad words. This encoding is a character substitution algorithm by rotating a letter 13 places after it. Lower case characters are equally converted while anything else is passedthrough. Examples iex&gt; CouponCode.rot13(&quot;ABCDEFGHIJKLMNOPQRSTUVWXYZ&quot;) &quot;NOPQRSTUVWXYZABCDEFGHIJKLM&quot; iex&gt; CouponCode.rot13(&quot;abcdefghijklmnopqrstuvwxyz&quot;) &quot;nopqrstuvwxyzabcdefghijklm&quot; iex&gt; CouponCode.rot13(&quot;1234567890!@#$%^&amp;*()&quot;) &quot;1234567890!@#$%^&amp;*()&quot; iex&gt; CouponCode.rot13(&quot;Hello World!&quot;) &quot;Uryyb Jbeyq!&quot;","ref":"CouponCode.html#rot13/1","title":"CouponCode.rot13/1","type":"function"},{"doc":"Validates a receipient entered code based on the required parts and length it should have. With an entered code, it is normalized with the following steps: It is uppercased All non-word (0-9A-Z) characters are removed Similar letters (OIZS) are corrected (0125) If the normalized code is valid, this returns {:ok, corrected_code}. If the number of computed parts are invalid, it returns {:error, :parts_invalid, actual_parts}. Lastly it returns {:error, :part_invalid, part_with_error} for the first parsed part that has an checkdigit error. Options This function takes a keyword options as the second argument: parts - The number of expected delimited segments to generate. Defaults to 3 or Application.get_env(:coupon_code_ex, :parts) and must be a positive integer. part_length - The number of expected characters per each part. Defaults to 4 or Application.get_env(:coupon_code_ex, :part_length) and must be a positive integer between 2 - 20 inclusively. Examples iex&gt; CouponCode.validate(&quot;7B5M-LJ4J-D5FN&quot;) {:ok, &quot;7B5M-LJ4J-D5FN&quot;} iex&gt; CouponCode.validate(&quot;7B5MLJ4JD5FN&quot;) {:ok, &quot;7B5M-LJ4J-D5FN&quot;} iex&gt; CouponCode.validate(&quot;7B5mlJ4jd5fn&quot;) {:ok, &quot;7B5M-LJ4J-D5FN&quot;} iex&gt; CouponCode.validate(&quot;7B5mlJ4jd5fn&quot;, parts: 4) {:error, :parts_invalid, 3} iex&gt; CouponCode.validate(&quot;7B5mlJ4jd5fn&quot;, part_length: 5) {:error, :parts_invalid, 2} iex&gt; CouponCode.validate(&quot;7B5mlJ4jd5fM&quot;) {:error, :part_invalid, 2} iex&gt; CouponCode.validate(&quot;i9oD-V467-8Dsz&quot;) {:ok, &quot;190D-V467-8D52&quot;}","ref":"CouponCode.html#validate/2","title":"CouponCode.validate/2","type":"function"},{"doc":"CouponCode ![BuildS tatus](https://github.com/FrancisMurillo/coupon_code_ex/workflows/.github/workflows/elixir.yml/badge.svg)","ref":"readme.html","title":"CouponCode ![BuildS","type":"extras"},{"doc":"If available in Hex, the package can be installed by adding coupon_code_ex to your list of dependencies in mix.exs: def deps do [ {:coupon_code_ex, &quot;~&gt; 0.1.0&quot;} ] end Documentation can be generated with ExDoc and published on HexDocs. Once published, the docs can be found at https://hexdocs.pm/coupon_code_ex.","ref":"readme.html#installation","title":"CouponCode ![BuildS - Installation","type":"extras"}]